@@ -24,6 +24,7 @@
 #include <unistd.h>
 
 #include "kanjipad.h"
+#include "gtkglyphlabel.h"
 
 typedef struct {
   gchar d[2];
@@ -80,6 +81,9 @@ static void
 karea_draw_character (GtkWidget *w, int index, int selected)
 {
   gchar str[3];
+  GdkFont *font;
+
+  font = gtk_object_get_data (GTK_OBJECT (w), "font");
 
   if (selected >= 0)
     {
@@ -94,7 +98,7 @@ karea_draw_character (GtkWidget *w, int index, int selected)
   str[1] = kanjiguess[index].d[1];
   str[2] = 0;
 
-  gdk_draw_string(kpixmap, w->style->font,
+  gdk_draw_string(kpixmap, font,
 		  (selected > 0) ? w->style->white_gc :
 		                   w->style->black_gc,
 		  3, 24 + 30*index, str);
@@ -442,7 +446,9 @@ main (int argc, char **argv)
   GtkItemFactory *factory;
   GtkAccelGroup *accel_group;
 
-  GtkStyle *style;
+  static guint16 lookup_string[] = { 0x7a30, 0 };
+  static guint16 erase_string[] = { 0x433e, 0 };
+
   GdkFont *font;
   int i;
   char *p;
@@ -533,6 +539,10 @@ main (int argc, char **argv)
   karea = gtk_drawing_area_new();
   gtk_drawing_area_size (GTK_DRAWING_AREA(karea), 30, 0);
 
+  font = gdk_font_load ("-*-fixed-medium-r-*--24-*-jisx0208.1983-0");
+
+  gtk_object_set_data (GTK_OBJECT (karea), "font", font);
+
   gtk_signal_connect (GTK_OBJECT (karea), "configure_event",
 		      GTK_SIGNAL_FUNC (karea_configure_event), NULL);
   gtk_signal_connect (GTK_OBJECT (karea), "expose_event",
@@ -549,26 +559,15 @@ main (int argc, char **argv)
 
   gtk_widget_set_events (karea, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
   
-  style = gtk_style_new();
-  font = gdk_font_load ("-*-fixed-medium-r-*--24-*-jisx0208.1983-0");
-  gdk_font_unref (style->font);
-  style->font = font;
-
-  gtk_widget_set_style (karea, style);
-  
   gtk_box_pack_start (GTK_BOX (vbox), karea, TRUE, TRUE, 0);
   gtk_widget_show (karea);
 
   /* Buttons */
 
-  label = gtk_label_new ("\x30\x7a");
-  /* We have to set the alignment here, since GTK+ will fail
-   * to get the width of the string appropriately...
-   */
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_widget_set_style (label, style);
+  label = gtk_glyph_label_new (font);
+  gtk_glyph_label_set_string16 (GTK_GLYPH_LABEL (label), lookup_string);
   gtk_widget_show (label);
-
+  
   button = gtk_button_new ();
   gtk_container_add (GTK_CONTAINER (button), label);
   gtk_signal_connect (GTK_OBJECT(button), "clicked",
@@ -577,9 +576,8 @@ main (int argc, char **argv)
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
   
-  label = gtk_label_new ("\x3e\x43");
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_widget_set_style (label, style);
+  label = gtk_glyph_label_new (font);
+  gtk_glyph_label_set_string16 (GTK_GLYPH_LABEL (label), erase_string);
   gtk_widget_show (label);
 
   button = gtk_button_new ();
